package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````/"````````!``````````,BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````'6@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````.)@`````
M```XF``````````0`````````0````8```"0FP```````)"K````````D*L`
M``````#`!````````.@$`````````!`````````"````!@```*B;````````
MJ*L```````"HJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```"PCP```````+"/````````L(\```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````D)L```````"0
MJP```````)"K````````<`0```````!P!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`*L:2-<65%,^A?H5LE,N-/_L(UNV!````!`````!````1TY5```````$````
M#P`````````1````2`````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````2````$L```!.````3P```%<```!8````6@```%P`
M``!=````7@```&````!B````8P```&4``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`)`>``````````````````#N`@``$0``````````````````
M``````#5````$@````````````````````````#Z`0``$@``````````````
M``````````"J`0``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"R`0``$@``````
M```````````````````K`@``$@````````````````````````!E`0``$@``
M``````````````````````!:`@``$@````````````````````````#K````
M$@````````````````````````"G`@``$@````````````````````````#4
M`@``$0````````````````````````"Y`0``$@``````````````````````
M``#U`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````!D`@``$@````````````````````````"&`0``$@``````````
M```````````````D`@``$@`````````````````````````!`@``$@``````
M``````````````````#<`@``$@`````````````````````````!````(```
M``````````````````````!*`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(`````````````````````````"+
M`@``$@````````````````````````"!`@``$@``````````````````````
M```W````$@````````````````````````"2`@``$@``````````````````
M``````#2`@``$0````````````````````````!4````%@``````````````
M``````````#+`@``$@`````````````````````````^`0``$@``````````
M``````````````">`0``$@````````````````````````#(`0``$@``````
M``````````````````!G````$@````````````````````````!S`@``$@``
M``````````````````````#$````$@````````````````````````!X````
M$@````````````````````````!^`0``$@````````````````````````"H
M````$@````````````````````````#:````$@``````````````````````
M``!W`0``$@````````````````````````"X`@``$@``````````````````
M```````P`0``$@`````````````````````````=`@``$@``````````````
M```````````R`@``$@````````````````````````!Z`@``$0``````````
M``````````````#?````$@````````````````````````#M`0``$@``````
M``````````````````"*`@``$@````````````````````````#6`0``(@``
M``````````````````````"3````$@````````````````````````#E`0``
M$@````````````````````````"E`0``$@````````````````````````!3
M`@``$@````````````````````````!9`0``$@``````````````````````
M```(`@``$@````````````````````````"V`P``$@``````````````````
M``````"W````$0````````````````````````"9`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M``````````````",`0``$@````````````````````````#``0``$@``````
M``````````````````"^`@``$@`````````````````````````Y`@``$@``
M```````````````````````6`@``$@````````````````````````"_`P``
M$@`,`$`W````````M@````````!1!```$@`,`$(P````````.`4```````"9
M`0``$@`,`)`>````````K`$````````V`P``$@`,`!@G````````#```````
M``!4`P``$@`,`'HU````````Q@$```````!W!```$@`,`"0G````````O`$`
M```````W!```$``6`%"P``````````````````!'`P``$@`,`.`H````````
M*`````````!J`P``$@`,`'@M````````6@````````#7`P``$0`-`#A.````
M````!``````````4!```$@`,`(1+````````Z@`````````O!```$@`,`"PF
M````````,@````````!,!```$``6`'BP``````````````````!E!```$@`,
M`%8O````````[`````````".!```$@`,`-(M````````4`````````#F`P``
M$``5``"P``````````````````".`P``$@`,``@I````````\@`````````"
M!```$`#Q_P"X``````````````````!>!```$``5`%"P````````````````
M``"$!```$0`5`$BP````````"``````````?!```$``5`%"P````````````
M``````#L`P``$@`,`#P@````````(@````````#S`P``$``5``"P````````
M``````````!#!```$@`,`"I+````````6@````````#H`P``(``5``"P````
M``````````````#+`P``$``6`'BP``````````````````"D`P``$@`,`#@O
M````````'@````````!X`P``$@`,`%XF````````N@````````":`P``$@`,
M`&Y,````````N`$```````"6!```$@`,`/HI````````?@,`````````7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!S=')C:'(`;'-E96LV-`!R;61I<@!?7VQI8F-?<W1A<G1?
M;6%I;@!S=')C;7``<F5A9`!S=')N8VUP`&=E='5I9`!A8V-E<W,`;W!E;F1I
M<@!?7VUE;6UO=F5?8VAK`%]?8WAA7V9I;F%L:7IE`')E86QL;V,`<W1R<F-H
M<@!E>&ET`'-T<G1O:P!U;FQI;FL`7U]F<')I;G1F7V-H:P!O<&5N-C0`<W1R
M9'5P`'-T<G-T<@!S=')L96X`;65M8VAR`%]?<W1A8VM?8VAK7V9A:6P`<F5A
M9&QI;FL`;65M<V5T`')E861D:7(V-`!?7W9F<')I;G1F7V-H:P!M96UC;7``
M<W1D97)R`&-L;W-E9&ER`&QS=&%T-C0`;65M8W!Y`%]?<W!R:6YT9E]C:&L`
M7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!?7VUE;6-P>5]C:&L`9V5T<&ED`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`&QD+6QI;G5X+7)I<V-V-C0M;'`V
M-&0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E
M<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C
M7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%])3U]S=&1I;E]U
M<V5D`%]?9&%T85]S=&%R=`!?7T1!5$%?0D5'24Y?7P!?7V=L;V)A;%]P;VEN
M=&5R)`!S:&%?=7!D871E`%]?4T1!5$%?0D5'24Y?7P!X<U]I;FET`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`
M<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(W
M```````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,`
M`P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!``$``P`!
M``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!``$`
M!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``P`0`P``$````$````"TD98&
M```%`*,$```0````LY&6!@``!`"N!```$````(>1E@8```,`N00````````!
M``$`&@,``!``````````AY&6!@```@"Y!````````)"K`````````P``````
M``!>(````````)BK`````````P````````#R(````````*"K`````````P``
M``````"X(````````/BO`````````P````````"0'@````````"P````````
M`P``````````L````````!BP`````````P````````"83P```````""P````
M`````P``````````4@```````"BP`````````P`````````(4@```````#"P
M`````````P`````````04@```````#BP`````````P`````````84@``````
M`$BP`````````P`````````@4@```````*"O`````````@````(`````````
M`````*BO`````````@````P``````````````+"O`````````@````X`````
M`````````+BO`````````@```!D``````````````,"O`````````@```!P`
M`````````````,BO````````"P```"(``````````````-"O`````````@``
M`"0``````````````-BO`````````@```"<``````````````."O````````
M`@```#,``````````````.BO`````````@```#<``````````````/"O````
M`````@```#\``````````````,BM````````!0````,``````````````-"M
M````````!0````0``````````````-BM````````!0````4`````````````
M`."M````````!0````8``````````````.BM````````!0````<`````````
M`````/"M````````!0````@``````````````/BM````````!0````D`````
M``````````"N````````!0````H```````````````BN````````!0````L`
M`````````````!"N````````!0````T``````````````!BN````````!0``
M``\``````````````""N````````!0```!```````````````"BN````````
M!0```!$``````````````#"N````````!0```!(``````````````#BN````
M````!0```!,``````````````$"N````````!0```!0``````````````$BN
M````````!0```!4``````````````%"N````````!0```!8`````````````
M`%BN````````!0```!<``````````````&"N````````!0```!@`````````
M`````&BN````````!0```!H``````````````'"N````````!0```!L`````
M`````````'BN````````!0```!T``````````````("N````````!0```!X`
M`````````````(BN````````!0```!\``````````````)"N````````!0``
M`"```````````````)BN````````!0```",``````````````*"N````````
M!0```"4``````````````*BN````````!0```"8``````````````+"N````
M````!0```"@``````````````+BN````````!0```"D``````````````,"N
M````````!0```"H``````````````,BN````````!0```"L`````````````
M`-"N````````!0```"P``````````````-BN````````!0```"T`````````
M`````."N````````!0```"X``````````````.BN````````!0```"\`````
M`````````/"N````````!0```#```````````````/BN````````!0```#$`
M``````````````"O````````!0```#(```````````````BO````````!0``
M`#0``````````````!"O````````!0```#4``````````````!BO````````
M!0```#8``````````````""O````````!0```#@``````````````"BO````
M````!0```#D``````````````#"O````````!0```#H``````````````#BO
M````````!0```#L``````````````$"O````````!0```#P`````````````
M`$BO````````!0```#T``````````````%"O````````!0```#X`````````
M`````%BO````````!0```$```````````````&"O````````!0```$$`````
M`````````&BO````````!0```$(``````````````'"O````````!0```$,`
M`````````````'BO````````!0```$0``````````````("O````````!0``
M`$4``````````````(BO````````!0```$8``````````````)"O````````
M!0```$<`````````````````````````EY,``#,#PT$#OH,N$P-#_9."@RX3
M4Q,`@[*"`&<`#@`7G@```SZ.+6<##@`3````%YX```,^#BUG`PX`$P```!>>
M```#/HXL9P,.`!,````7G@```SX.+&<##@`3````%YX```,^CBMG`PX`$P``
M`!>>```#/@XK9P,.`!,````7G@```SZ.*F<##@`3````%YX```,^#BIG`PX`
M$P```!>>```#/HXI9P,.`!,````7G@```SX.*6<##@`3````%YX```,^CBAG
M`PX`$P```!>>```#/@XH9P,.`!,````7G@```SZ.)V<##@`3````%YX```,^
M#B=G`PX`$P```!>>```#/HXF9P,.`!,````7G@```SX.)F<##@`3````%YX`
M``,^CB5G`PX`$P```!>>```#/@XE9P,.`!,````7G@```SZ.)&<##@`3````
M%YX```,^#B1G`PX`$P```!>>```#/HXC9P,.`!,````7G@```SX.(V<##@`3
M````%YX```,^CB)G`PX`$P```!>>```#/@XB9P,.`!,````7G@```SZ.(6<#
M#@`3````%YX```,^#B%G`PX`$P```!>>```#/HX@9P,.`!,````7G@```SX.
M(&<##@`3````%YX```,^CA]G`PX`$P```!>>```#/@X?9P,.`!,````7G@``
M`SZ.'F<##@`3````%YX```,^#AYG`PX`$P```!>>```#/HX=9P,.`!,````7
MG@```SX.'6<##@`3````%YX```,^CAQG`PX`$P```!>>```#/@X<9P,.`!,`
M```7G@```SZ.&V<##@`3````%YX```,^#AMG`PX`$P```!>>```#/HX:9P,.
M`!,````7G@```SX.&F<##@`3````%YX```,^CAEG`PX`$P```!>>```#/@X9
M9P,.`!,````7G@```SZ.&&<##@`3````%YX```,^#AAG`PX`$P```!>>```#
M/HX79P,.`!,````7G@```SX.%V<##@`3````%YX```,^CA9G`PX`$P```!>>
M```#/@X69P,.`!,````7G@```SZ.%6<##@`3````%YX```,^#A5G`PX`$P``
M`!>>```#/HX49P,.`!,````7G@```SX.%&<##@`3````%YX```,^CA-G`PX`
M$P```!>>```#/@X39P,.`!,````7G@```SZ.$F<##@`3````%YX```,^#A)G
M`PX`$P```!>>```#/HX19P,.`!,````7G@```SX.$6<##@`3````'7&&[*+H
MRN"`$*;D3OQ2^*J'%YD```,YZ0\C.+3Z(S3$^I,%!/L3!H3Z$P7$^R,N]/J#
M-PD`(S3T_(%'[_!?]A>6```#-H8-LH47E0```S7E#^\@4'27EP``@[>G$(/'
M!P!CA0<.EY<``(.W)PV7E```DX2D%9*7F&.#*<3[@T>G2QN%20`.!9/G-P`C
M#?=*[_`?[(,U!/N#)\3[B.2888TIJH88X1<W```3!Z<K&.47EP```S>'$!CI
M%S<``!,'YRH8[05'8USW#!N(-P!"AJ$%$4>(89,7-P"VEP4GB..A!>,9!_^;
M!P8`C@>(;+:7`4=.AI<%``"3A85D([`'`._P'[HUR8AL$PI$_._P7]JJB=*%
M%S4``!,%1?CO`(`4)<&(;._PW[/O\)_+`S>$_(,W"0"YCP%'I>OF8$9DIF0&
M:4)Z3H7B>25A@H#O\%_&EY0``).$A`>(["'%[_!?SY>7``"#MX?]A68SAT<`
M&&,VER,'!YH!MXAL[_!_NF&WB&@!Q>\0P')IO]*%%S4``!,%1>GO```-B.A!
MU>6WD4>IMP5%[_#?MN_PG^/O`"`"JH<7E0```S5E^X)E,``3<0'_@48!1PJ(
M[_"?W@*0EY$``).!(7J"@```%Y4``!,%9?Z7EP``DX?G_6.(IP"7EP``@[>G
M\Y'#@H>"@!>5```3!47\EY4``).%Q?N)C9/7-4#]D;Z5A869Q9>7``"#MV?Q
MD<."AX*`01$BX!>4```3!$3Y@T<$``;DA>.7EP``@[?'\9''%Y4```,UI?*"
ME^_PO_B%1R,`]`"B8`)D00&"@&F_77&BX(;D)OR`"%')7N27EP``@[?GZH.[
M!P!CA`L(3O12\%;L@T<%`"J*KHJJB1,'T`.]RV.&YP"#QQD`A0G]^[N)24&#
MM`L`M<!*^%KH7HD3"]`#3H;2A2:%[_`_G+.'-`$)Y8/'!P!C@F<#@S2)`"$)
M[?!">:)Y`GKB:D)KHFNF8`9D)H7B=&%A@H`S"7E!$UDY0(4)(Z`J`<Z4X;^!
M1,6WHFN!1.F_@4EIOZ)Y`GKB:J)K\;=Q<2+Q)NU*Z0`9!O47F0```SFIWI,%
MA/6#-PD`(SST_(%'JH3O\#^\%>&#)X3VO6819_6/8X7G`"EG8YKG`(E%)H7O
M\%^:$S45`!&@`44#-X3]@S<)`+F/`4>9YZIP"G3J9$II36&"@._P_\55<:+A
M4O&&Y8`)%YH```,Z"MB#-PH`(SST^H%'&<4F_8-'!0"JA)GOZG0#-X3[@S<*
M`+F/`4=CF@<,KF`.9`IZ:6&"@$KY3O7O\#^_*HE)S4J%[_"?D%G!@T8U`9,)
M-0&;AB;]@>:#QAD`_=(#1S4!&P<G_37/)H56[>_P'XRJBDZ%[_"?B[N*J@")
M*E:%[_#?B\Z')H>7-@``DX9&N5:&B46JB>_P?[63!83S3H7O\-^8_5=C"?4`
M@R>$]+UF$6?UCV.`YP1.A>_P/Y-.A>_PWZ)*A>IJ[_!?B#W]2H7O\-^6)H7O
M\'^/ZG1*>:IY-;\#QQD`&P<G_3W_`\<I`"G;G;].A>_PW^_1MR;]2OE.]5;M
M[_"?M%EQHO"F[,KHSN16_(;TTN!>]&+P@!B#QP4`EYD``(.YJ<4JB9.'-_R3
MMQ<`LX3U`":%@[<)`",\]/B!1^_PC_ZJBI,%1/E*A>_P']AYS2J*[_!/_6-Z
M50N#*T3Y%YP```,\C,*."P-'"0#*AY,&T`-C``<48P;7``/'%P"%!WW[NX<G
M00,Z#``3A2H`/I5>FN_P3_HC,*H`,<4#-PP`@T<)`!,%&0!>EQ1C$P;0`R.`
M]@"!ZXVH@T<%``4%HP#W`+W#-H>%!N.8Q_Z3!M`#DP<7`",`UP`#QP0`A0>%
M!*./Y_YU^P,WA/F#MPD`N8\!1^GGIG`&=.9D1FFF:09JXGJB>P)\96&"@(/'
M!``%"H4$HP_Z_N';@\<$``4*A02C#_K^_?/!MS:'3;=:^&;L:N@7G````SQ,
MM0,]#`"#-PT`M<OJAP%*F&?2AJ$'!2IE_XTF$YLV`)>7``"3AV>]F$,-[P5'
M6H68P^_PS^RJC#G)DQLZ`-J&7H;JA>_POX`C,)P!FP<:`(X'OIPCL`P`0GOB
M;$)M(RI$^?FUVH5JA>_P?XXC,*P`JHP1S9,;.@#1OX%'R;U!2P%*>;]:^&;L
M:NCO\%^80GOB;$)M*;]=<:+@)OQ*^$[T4O!6[(`(AN3]=_URDX>'^X5DEYD`
M`(.YR:@6D:J*+HH3AO3_LX6'`!<U```3!>61@[<)`",\]/J!1^_P3^\;"04`
M8UT@`1,'!/RS!)=`FP?Y_[Z4`\>$_QWOC>^7EP``@[>GIE*&UH62EXAC[_`O
MY@,WA/N#MPD`N8\!1ZGGA6(6D:9@!F3B=$)YHGD">N)J86&"@#Z)_7>3AX?[
MLX2'`$J&DP7P`B:%[_!O^T79EY<``(.WAZ'*AB:&DI>(8]:%[_#O\W6W[_"?
MB@$1)N27E```@[2$GR+H!NP`$+.'1`"(8Y=V``"3AL::%Y8```,V1IZ7-0``
MDX5%AN_P7X*2E$)DB&#B8*)D%S<``!,'Y[V!1[J&%Q8``!,&1O:7-0``DX6E
MA05A;_"/ZD$1EY<``(.WIYDBY``((F22EXACEW8``).&!I47E@```S:&F)<U
M``"3A86`00%O\&_\'7&&[*+HIN2`$,K@3OQ2^%;T^7(7F@```SKJDA:1@S<*
M`",\]/J!1^_PK^#Y=Y.'A_JSA(<`!68JAY<G``"3AX=_ER8``).&AG\%!HE%
M)H7O\"_V_763AP7[,XF'`":%!6;*A>_P[]:;!`4`@4ECP00"FXH4`%:%[_"O
MR*J)"<DFAM:&RH7.E._PK_<C@`0``S>$^X,W"@"YCP%'B>^)8A:1YF!.A49D
MIF0&:>)Y0GJB>B5A@H#O\,_U01$BY``((F1!`36_$7&B^:;URO'.[6+Y``*&
M_=+IUN7:X5[]9O5J\6[M_7?]<I.'1_`7G````SQLA1:1*HFNB1<E```3!85U
MLX6'`(,W#``C-/3X@4?O\'^8JH23!?`"2H7O\&_:,<$7)0``$P4%=,J%[_`_
MNDJ%`S>$^(,W#`"YCP%'8Y`'%(5B%I'N<$YTKG0.>>YI3FJN:@YKZGM*?*I\
M"GWJ;1%A@H!.A>_PS]B7)0``DX6%<._P#[,JC4W5_7E]>I.'B?BSB8<`DP>*
M\(5J,XJ'`),'!/FSC%=!@T<-`)<K``"3B^MM%RL``!,+ZVW)RY'$ZH4FA>_P
M[\@UQ6J%[_!OLY,']?_JEZJ-DP;P`F-H_0`QJ".`!P#]%V,&_0`#QP<`XPG7
M_FJ%[_#/L*J-2H7O\$^P;I4%!>-V5?.)14J(WH=JA]J&!69.A>_PK]K2A4Z%
M[_`OO@'I@Z>,^+UF(6?UCV./YP*7)0``DX7E9`%%[_!/IRJ-XP<%[H-'#0"M
M^Y'$@\<$`)N')_V9QX5-%RT``!,-[5]AOX/'%`#IU_VWA45.A>_P#ZU=_<Z%
M%R4``!,%A5_O\-^E3H7O\*_'7;WO\$_9`1$BZ";D!NP`$),%\`*JA._P#\D9
MP9,$%0!"9.)@)H6B9`5A;_#/Q#EQ(OA.[`;\)O1*\(``EXD``(.YJ6C]<H.W
M"0`C-/3\@4<6D5G)@T<%`"J)V<?O\*^A$P85`(5GJH1CZ,<*?7>3!X?\,X>'
M`,J%.H7O\,^RDX?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#QP<`XPG7_GUU
MDP>%_+.$AP"3!?`")H7O\&^_%<EC[J0$?763!X7\,X6'`._P+[L#-X3\@[<)
M`+F/`4>AYX5B%I'B<$)THG0">>)I(6&"@`,WA/R#MPD`N8\!1X7GA6(6D>)P
M0G2B=`)YXFD7)0``$P6E3"%A;_"/MB,`!0!5MP%%?;?O\*_'.7$B^";T2O!.
M[%+H@``&_!>)```#.6E9@S<)`",T]/R!1Y,$1/R7*0``DXF)3!>*```#.HI8
MIH5.A>_P#^P=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_PS^EY
M_9<I``"3B:E)%XH```,ZJE2FA4Z%[_`OZ!W!`R=$_(,W"@`.![J7F&>8XWW3
MF&NA!YCC;?^FA4Z%[_#OY7G]ERD``).)2487B@```SK*4*:%3H7O\$_D'<$#
M)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\`_B>?V7*0``DXEI0Q>*
M```#.NI,IH5.A>_P;^`=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.
MA>_P+]YY_9<I``"3B0E`%XH```,Z"DFFA4Z%[_"/W!W!`R=$_(,W"@`.![J7
MF&>8XWW3F&NA!YCC;?^FA4Z%[_!/VGG]ERD``).)*3T7B@```SHJ1::%3H7O
M\*_8'<$#)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\&_6>?V7*0``
MDXG),1>*```#.DI!IH5.A>_PS]0=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8
MXVW_IH5.A>_PC])Y_9<I``"3B6DV%XH```,Z:CVFA4Z%[_#OT!W!`R=$_(,W
M"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%[_"OSGG]ERD``).)B3,7B@```SJ*
M.::%3H7O\`_-'<$#)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\,_*
M>?V7*0``DXFI,!>*```#.JHUIH5.A>_P+\D=P0,G1/R#-PH`#@>ZEYAGF.-]
MTYAKH0>8XVW_IH5.A>_P[\9Y_9<I``"3B4DC%XH```,ZRC&FA4Z%[_!/Q1W!
M`R=$_(,W"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%[_`/PWG]IH47)0``$P7%
M*>_P#\*JA1G%%R4``!,%Q2;O\(_DIH47)0``$P5E*>_P+\"JA1G%%R4``!,%
MY2GO\*_BIH47)0``$P4%*N_P3[ZJA1W-%R4``!,%A1GO\,_@`S>$_(,W"0"Y
MCP%'L>-"=.)PHG0">>)I0FJ7)0``DX4E*1<E```3!24=(6%O\,_=IH47)0``
M$P4E)N_P;[FJA6'1%R4``!,%)1WO\._;3;_O\,^/>7$B\";L`!@&])>$``"#
MM.0ADP5$_1<E```3!:4:G&`C//3\@4?O\&^U!<6#1P4``46)QY.'!_TS-?``
M`S>$_9Q@N8\!1X'KHG`"=.)D16&"@`%%Y;?O\"^*'7$BZ`;L`!`JCA>%```#
M-44@"&$3`X0`#.00Z!3L'/08\",X!`,C/!0#EX<``(.W1QJ:AG*&B4688R,T
MY/X!1R,P9/[OX+_<$P7P#^_@/]A9<:+PTN!6_&KHAO2F[,KHSN1:^%[T8O!F
M[(`8P7(7C0```ST-%H,W#0`C//3X@4<6D0E&@46JBN_@?^D3"O7_$U?Z0T&3
MLP?J`,(7P9.9CS,*^D!C00H*07E!;),'"?E]6S.)AP`A#)U,EXD``).)R1?!
M>P%&TH56A>_@7^5C!&4)8H;*A5:%[^!_\0$E8P9E!V/_K`1A%;,$J0!C]B0!
M@:C]%&/F)`4A1LZ%)H7OX!_?9?G!=Y.'!_FBES.%]$!2E0,WA/F#-PT`N8\!
M1['CP6(6D:9P!G3F9$9IIFD&:N)Z0GNB>P)\XFQ";65A@H!>FN,1>OE]5>FW
M%R4``!,%Q0SO\/_J%R4``!,%!0OO\#_J[^#?\T$1(N`&Y``([^`?P`$E[^"_
MZQ'!"&&B8`)D00&"@#EQ(OA*\$[L@``&_)>)``"#N>D#*HF3!43\%R4``!,%
MA0B#MPD`(S3T_(%'[_`OEPW))O2#1P4`JH2=P\J%[^#?QCG!`S>$_(.W"0"Y
MCP%'V>?B<$)THG0">>)I(6&"@*)T`S>$_(.W"0"YCP%'RH47)0``$P4E`[7G
M0G3B<`)YXFDA86_P+[5*A5+H[^#_MBJ*)H7OX'^V*IH)"E*%[^#?MB:(ER<`
M`).'9^U*AY<F``"3AL;M4H:)1:J$[^#_WP,WA/R#MPD`N8\!1Y'KIH5":J)T
M%R4``!,%Y?QYOU+H[^"_XR;T4NCOX#_C)7$BZTKC`!/._M+Z!N\FYY>'``"3
MAV?[@[@'`0.XAP&0<Y1WF'N<?Q>*```#.FKS`S,*`",\9/@!0Q<C```3`T/Y
M$PG$YR,\].R7)P``DX?'^*J)(S!DZ",\].@7(P``$P.CX)<G``"3AZ?WRH47
M)0``$P4%X",T9.@C.`3H(S@4ZR,\!.LC,,3L(S34[",XY.PC,/3J(S0$ZN_P
MCX$1Q8-'!0"JA&.0!R36]MKRWN[BZN;F[^"_I`$E[^!?T&,*!1B#.P4`8X8+
M&%Z%[^`_I),4%0"%!":%[^!_I`/'"P`JC*:,JHH-SQ<K```3"VOPVH8FAHE%
M8H7OX'_-A0OFAF/SG`"FAK.'ED")!V/SUP"VAP/'"P#Y%)6,OI0)#&G[$PL$
MZQ<E```3!27C*:`#-8L`(0L-P<J%[^"_]ZJ$9=F#1P4`[=?O\"^"==$FA>_@
M'[RJA!7A$PL$Z(,T"P")S(/'!`!CA0<.)H7OX/__8>F#-(L`(0OM]":%[^!?
MF2J+5H7OX-^8.PNK`!L+2T!:A>_@_YB7)P``DX<GT-:(%R@``!,(B.4FAY<F
M``"3AF;E6H:)1:J+[^"?P9,%`!Q>A>_@_[+]5V,8]0#OX%^7'$%%1V.:YPZ3
M!03N7H7OX#^WJH0!Z8,G!.^]9A%G]8]CB><*EX<``(.WQ]J#M@D`B&->AQ<F
M```3!L;DB47OX#^Z@4H#-X3Y@S<*`+F/`4=CD@<P^F!:9!9[]FM6;+9LNF0:
M:?9Y5GI6A;9Z'6&"@":%[^#_K*J$(0OC"07P-;>!1"6W`S6$Z9,$A.D9R<J%
M[^!?Y0'%@T<%`)7CB&2A!'WU-47OX-^**HRJBK5,M427*P``DXN+U!,',`6Y
MO>_@/ZBJBV'=[^"_AY,4%0"%!"6]@RJ$[^_@OX6;!P4`XY/Z](,G!._JXA,'
M`!R3]_<?8XCG!!9M/;<7AP```S>'S8.V"0`(8Q<F```3!J;37H>)1>_@_ZPU
MM^_P_\(#-X3Y@S<*`+F/`4=CF0<B6F3Z8!II]GE6>B:%NF0=86_@7Z!:A>_@
M_X#*A:J*%R4``!,%Y=COX#_9JH5C#040`[4)`._P3[NJC&,&!1!FA>_@3_T;
M#`4`C4=CV(<#$P7,_Y<E``"3A2769I7OX)^0">V11V,&_!B;![S_YI<#QP<`
MDP?P`F,-]Q;*A1<E```3!06X[^!?TW'!@T<%`-W/$P<``V.,YPJ7)0``DX7%
MOQ<E```3!<6U[^"?]._@GXHJB)<H``"3B*C?ER<``).')ZY>AY<F``"3A@;2
M6H:)15:%[^`_H'U9Q4D7+0``$PTMW9<L``"3C*RK%RP``!,,K-`EH._@#_4<
M06.7-P/OX'^%A20JB&K@IHCFAUZ'XH9:AHE%5H7OX/^;DP4`'%:%[^!?C>,(
M)?U>A>_@OXK6A1<E```3!46D[^"?ZU:%[_#?K19MT;N#O`D`U;V!16:%[^!?
MGRJ)*='O\/^8JHGC307RDP5E_P%&2H7OX+^$$PP$]AE&XH5*A>_@WY"91V,?
M]0@#)P3VMT=!0Y.'!S#C%??P`U=,`)%GDX>'5.,>]^X!1I.%Z?Q*A>_@WX"3
M!(3V$P:``J:%2H7OX-^,DP>``F,>]027*```DXB(SB:(ER<``).'YYQ>AY<F
M``"3AL:_6H:)15:%(P@$^._@OXXMOX.YB0#C@PGH3H7OX*_AC4?C_:?F<167
M)0``DX5ENTZ5[^!/]>,3!>;.C(6U%R4``!,%A;KO\#^'ZN+OX+^0UO;:\M[N
MXNKFYNKB[^"_CUUQ)OR7A```@[2DI*+@3O12\(;D2OA6[(`(LX=$``.Y!P`3
M"D3[EXD``(.Y":"#1PD+TH47)0``$P6EE@.W"0`C/.3Z`4>C"/D*[^`?LQG%
M`T<%`),'$`-C`?<4[_!/PK.'1``#N0<`2H6-1@5&ER4``).%!;;OX`_=*HD%
MQ1QI,X=$``ACC&,7)@``$P;FM._@;]R#-PD!C&/<11.7EP)C2P<0LX=$`(AC
MC48%1I<E``"3A06S[^`/V2J)EXH``).**J(5P=*%%R4``!,%Y8?OX+^J*H9Y
MQ8,W"0$SAT0`"&.,8^_@+]>SAT0``[D'``5&ER4``).%1:]*A>_@K\JJA1<F
M```3!L:O2H7OX*_4DI2<8-*%%R4``!,%!8*CB`<*[^"?I2.XJ@"JA"G)DP4`
M'":%[^`OZ!L'%0"%1V/PYP+%1V,-]0"#MXH`JH8FAHQC%R4``!,%Q:WOX,_L
M`S>$^X.W"0"YCP%'H>^F8`9DXG1">:)Y`GKB:F%A@H`#M8H`[_!_E".XJ@"J
MA$WQ%R4``!,%A:?OX`_I@T<5`..%!^QMO0.WB@"#-PD!#&.(8^_@_]P5O[.'
M1`"(8^_@K^/5M>_@3_,Y<2+X)O1*\(``!OR7A```@[1$A2J)DP5$_!<5```3
M!>5]G&`C-/3\@4?OX+^8"<V#1P4`D<L3!P`#8X?G`&,%"0"#1PD`B>\#-X3\
MG&"YCP%'N>_B<$)THG0">2%A@H!*A4[L[_!/EI,%\`*JB>_@+]T9P9,)%0!.
MA>_@;]D11I<E``"3A86'[^"/M!G!XFEEOP,WA/R<8+F/`4>9ZT)TXFGB<*)T
M2H4">2%A;^"_HD[L[^#OYQ,!`=,C,($L(SR1*H`-(S01+",X(2LC-#$K(S!!
M*R,\42F7=```@[2$>),&A--!;OU>G&`C//3Z@4>3"(4#DP^%!S:(D]X.`C</
M_P`3#@[P`[8(`$$(H0B3508"$Q>&`9,3A@"35X8"DU*&`!-9A@,3DX4!,W?7
M`;/SXP&S]\<!,V=W`+/RP@&SYR<!,W/3`:(%,V=7`!M6A@&SYV<`L_7E`5&/
MS8\C..C^(SSX_N.1'_O]58,_!-H#/X3:`S<$VX,^A-0#/@35`S.$U8,X!-8#
M.(36@S,$UQ.)!B"!D1&@LH.P8IQBNH*A!K&/L\?W`;/'UP$3EQ<`_8-=CVV/
MN/[ZC_*.%H\:CD:#PH@>B..9)OT#.`4`@S^$TX,X!0$#/H4``S.%`8,^!0(W
MAH):$P:6F1-7N`&3%U@`V8^RGQ-?+@#MC_:?,\=H`),6[@&SYN8!_I<S=\<!
M@S\$U#/_M@`S1V<`NI<SQ^@![8\S=P<!LI^3DU<`$]FW`9J?,T<7`7Z7L^\C
M`9-9*`"3$N@!?I>#/X34L^(R`;/&5@#]CK*?;8^SQN8!QI^3D^<!B8.SX_,`
M$QE7`)-9MP&SA_8!@S\$U;-F.0&VE[/&<@"RG[/RL@#YCNV/?I^SQE8`$YE7
M`)/9MP&3'^<!^I8)@P,_A-6S[^\`,V<Y`;J6,\?S`>V.L_.S`'V/,I\6GQ.9
M5@"3V;8!,T=W`).2YP&)@[/B\@!ZE[-G.0$^ES-_MP`#-P36L\=?`/6/L_^_
M`#*7'I<3&5\`DUF_`;/']P&ZES-G.0&ZEY.3Y@&)@K/CTP"S]K<`@S>$UC/'
M<@`S=^<!L_*R`+*7_I<3F58`D]FV`3-'5P`^E[-G.0$^EY,?[P$37R\`L^_O
M`3-_MP`#-P37L\?S`?6/L_.S`#*7%I<3&5\`DUF_`;/'=P"ZES-G.0&ZEY.2
MY@&)@K/BT@"S]K<`@S>$US/'7P`S=^<!L_^_`+*7GI<3F58`D]FV`3-']P$^
ME[-G.0$^EY,3[P$37R\`L^/C`3-_MP`#-P38L\=R`/6/L_*R`#*7?I<3&5\`
MDUF_`;/'5P"ZES-G.0&ZEY.?Y@&)@K/OWP"S]K<`@S>$V#/'\P$S=^<!L_.S
M`+*7EI<3F58`D]FV`3-'=P`^E[-G.0$^EY,2[P$37R\`L^+B`3-_MP`#-P39
ML\=?`/6/L_^_`#*7'I<3&5\`DUF_`;/']P&ZES-G.0&ZEY.3Y@&)@K/CTP"S
M]K<`@S>$V3/'<@`S=^<!L_*R`+*7_I<3F58`D]FV`3-'5P`^E[-G.0$^EY,?
M[P$37R\`L^_O`3-_MP`#-P3:L\?S`?6/L_.S`#*7%I<3&5\`DUF_`;/'=P"Z
MES-G.0&ZEY.2Y@&)@K/BT@"S]K<`@S>$VC/'7P`S=^<!L_^_`+*7GI<3F58`
MD]FV`3-']P$^E[-G.0$^EY,3[P$37R\`L^/C`3-_MP`#-P3;L\=R`/6/L_*R
M`#*7?I<3&5\`DUF_`;/'5P"ZES-G.0&ZEY.?Y@&)@K/OWP"S]K<`@S>$VS/'
M\P$S=^<!LI>S\[,`EI>3$N\!$U\O`+/BX@$3F58`D]FV`0,_!-PS1W<`/I>S
M9SD!/I>SQU\`;8^S_[\`]8\RGQZ?$UFW`;/']P&3$U<`L^,C`?J7`SF$W!.?
MY@&)@C-OWP">E^V/L\;B`3*9L_*R`)/9MP'YCI.35P#*G[/&5@"SXS,!L_.S
M`/Z6GI:3'^<!@S,$W0F#L^_O`#/YM@`S1_\!LI,S?[\`DUFY`7V/$Q99`)Z2
M,T?G`3-F-@$6EVV.LP/'`).2YP$#-H3=B8.SXO(`-_?9;A,'%[JS^;,`L\=?
M`!/:N0&UCSJ6DY99`'J6[8^SYD8![8ZRES.&UP`3'^D!@S<$WA-9*0`S;R\!
ML\;B`3-YM@`S^K\`NI>SSW8`DU.Y`9,660"S_[\`TI>SYG8`_I?MCKZ6DY_I
M`8,WA-Z3V2D`L^\_`;/SM@"S2?\!,_JR`+J7L\+)`)/9LP$3EE,`L_*R`-*7
M,V8V`9:7;8X^EI,2Z0&#-P3?$UDI`+/B(@&SR5\`,WFV`#-ZOP"ZES//V0"3
M6;D!DQ99`#-_OP#2E[/F-@'ZE^V.OI83G^,!@S>$WY/3(P`S;W\`L\GB`;/S
MM@`S^K\`NI>SS\D`D]FS`1.64P"S_[\`TI<S9C8!_I=MCCZ6DQ_I`8,W!.`3
M62D`L^\O`;-)_P$S>;8`,_JR`+J7L\+9`)-9N0&3%ED`L_*R`-*7L^8V`9:7
M[8Z^EI.2XP&#-X3@D],C`+/B<@"SR5\`L_.V`#-ZOP"ZES//R0"3V;,!$Y93
M`#-_OP#2ES-F-@'ZEVV./I83'^D!@S<$X1-9*0`S;R\!L\GB`3-YM@`S^K\`
MNI>SS]D`DUFY`9,660"S_[\`TI>SYC8!_I?MCKZ6DY_C`8,WA.&3TR,`L^]_
M`+-)_P&S\[8`,_JR`+J7L\+)`)/9LP$3EE,`L_*R`-*7,V8V`9:7;8X^EI,2
MZ0&#-P3B$UDI`+/B(@&SR5\`,WFV`#-ZOP"ZES//V0"36;D!DQ99`#-_OP#2
ME[/F-@'ZE^V.OI83G^,!@S>$XI/3(P`S;W\`L\GB`;/SM@`S^K\`NI>SS\D`
MD]FS`1.64P"S_[\`TI<S9C8!_I=MCCZ6DQ_I`8,W!.,362D`L^\O`;-)_P$S
M>;8`,_JR`+J7L\+9`)-9N0&3%ED`L_*R`-*7L^8V`9:7[8Z^EI.2XP&#-X3C
MD],C`+/B<@"SR5\`L_.V`#-ZOP"ZES//R0"3V;,!$Y93`#-_OP#2ES-F-@'Z
MEVV./I83'^D!@S<$Y!-9*0`S;R\!L\GB`3-YM@`S^K\`NI>SS]D`DUFY`9,6
M60"S_[\`TI>SYC8!_I?MCKZ6DY_C`8,WA.23TR,`L^]_`+-)_P&S\[8`,_JR
M`+J7L\+)`)/9LP$3EE,`L_*R`-*7,V8V`9:7;8X^EI,2Z0&#-P3E$UDI`+/B
M(@&SR5\`,WFV`#-ZOP"ZES//V0"36;D!DQ99`#-_OP#2E[/F-@'ZE^V.OI83
MG^,!@S>$Y9/3(P`S;W\`L\GB`;/SM@`S^K\`NI>SS\D`D]FS`1.64P"S_[\`
MTI<S9C8!_I=MCCZ6DQ_I`8,W!.8362D`L^\O`;-YM@`S2?\!L_*R`!/:N0&Z
MES-)V0"3EED`,WFY`):7L^)&`1.:XP&3UB,`LV/:`,J7L_:R`+Z6@S>$YK/"
M?P`S^;8`,W^_`#/&P@"ZEY,260`36KD!^I<S?[8`^I<S[T(!^I<3END!`S\$
MYY/9*0`S9C8!L\G#`+/RMP"S_[\`L\?9`#J?$]JR`7Z?DYE2`+/_MP"SZ4D!
M?I].GY,6Z0$362D`L^8F`3?WQB,S>;8`_5>S=;\``S^$YX&3"@<3!\?-L__V
M`%6.LWGY`3J?,W96`+/S\P#ZDQ/:M0$S9C8!$Y_B`9.950"3TB(`,V]?`!Z6
ML^))`1:6@S($Z+-S_P"SYN8!?8ZS^7\`[8ZZDLJ2L^8V`1,95@"36;8!,VDY
M`9:6$YKE`<J6B8$#.83HLV6Z`+/R]0`S;[\`_8ZS^5,`,W_/`#J9,V\_`7Z9
MDYE6`!/:M@&3'^8!"8*S[\\`,P8O`3/O20%ZE@,_!.DS^?\`L^7U`7V.L_DB
M`3J?]8VSY34!^I.3&58`$UJV`1.?Y@&)@C-OWP"SAG4`L^5)`:Z6@S6$Z;-S
M_P"S[^\!_8ZS>7D`NI6S_\\`L^\_`:Z2DYE6`!/:M@&3%>8!"8+1C3.&7P"S
M[TD!?I:#/P3JL_+U`#-OOP!]CK/Y4P"ZGS-_WP`S;S\!?IF3&58`$UJV`9.?
MY@&)@K/OWP"S!B\!,^])`?J6`S^$ZC/Y_P"SY?4!_8ZS^2(!.I_QC;/E-0'Z
MDY.95@`3VK8!$Q_F`0F",V_/`#.&=0"SY4D!+I:#-03KLW/_`+/O[P%]CK-Y
M>0"ZE;/_WP"S[S\!KI*3&58`$UJV`9.5Y@&)@M6-LX9?`+/O20'^EH,_A.NS
M\O4`,V^_`/V.L_E3`+J?,W_/`#-O/P%^F9.95@`3VK8!DQ_F`0F"L^_/`#,&
M+P$S[TD!>I8#/P3L,_G_`+/E]0%]CK/Y(@$ZG_6-L^4U`?J3DQE6`!-:M@$3
MG^8!B8(S;]\`LX9U`+/E20&NEH,UA.RS<_\`L^_O`?V.LWEY`+J5L__/`+/O
M/P&NDI.95@`3VK8!DQ7F`0F"T8TSAE\`L^])`7Z6@S\$[;/R]0`S;[\`?8ZS
M^5,`NI\S?]\`,V\_`7Z9DQE6`!-:M@&3G^8!B8*S[]\`LP8O`3/O20'ZE@,_
MA.TS^?\`L^7U`?V.L_DB`3J?\8VSY34!^I.3F58`$]JV`1,?Y@$)@C-OSP`S
MAG4`L^5)`2Z6@S4$[K-S_P"S[^\!?8ZS>7D`NI6S_]\`L^\_`:Z2DQE6`!-:
MM@&3E>8!B8+5C;.&7P"S[TD!_I:#/X3NL_+U`#-OOP#]CK/Y4P`S?\\`NI_*
MGS-O/P$3F58`D]FV`3-I.0%^GTJ?,WG_`!,:Y@$#/P3O"8(S9LH`LW_V`-&-
ML_GR`?6-.I\>G[/E-0&3$UD`DUFY`1.:Y@'ZE8F",^\S`8,YA.^S9MH`L_/V
M`/J558XS__4`,W8F`;/U?P"ZF9:9$QI?`)-:OP%-CI-2*0"3%>D!3I8S:5H!
M2I8#.03PL^55`+/R]0#-CGV.L_E3`#J9L_;F`<J?L^8V`1,95@"36;8!_I:S
M;SD!_I:3&>\!@S^$\!-?+P"SZ>D!,_GY`+/E-0$S__8`L_HB`?&-NI^3%E\`
M$UJ_`9Z?L^55`;/C1@'^E9,6Y@&37R8`L^;V`;/S\P`SYMD`@SD$\9Z5L_/U
M`+/_]@"S>OD!$]JS`3-VY@&ZF1.74P"6F3-F5@&S8D<!3I:S\O(`LI*3&>\!
M`S:$\1-?+P`WMY@R,^_I`0H'$P=G';/&Y@&MCCJ62I;]CK/Y\@"REA.9XP$3
MUB,`LV/)`!/:N0&3E5D`,T9_`+/E10']C3-&5@"#,@3RMI4S^?4`NI(36KD!
MDQ99`):??8ZSYD8!_8Y^EC:6DY+I`8,VA/*3V2D`L^(R`;//4P"S>?8`,WK_
M`+J6,\^_`)/?N0&3E5D`,W__`-*6L^7U`?J6_8VVE1,?Z0&#-@3S$UDI`#-O
M+P&SS^(!,_GU`+/S\P`36KD!NI:SS\\`$Q99`+/__P">EC-F1@'^EGV.-I:3
MG^D!@S:$\Y/9*0"S[S\!LW/V`+-)_P$S^O(`NI:SPKD`D]FS`9.54P"S\O(`
MTI:SY34!EI;]C;:5DQ+I`8,V!/0362D`L^(B`;/)7P`S^?4`,WK_`+J6,\_)
M`)-9N0$3%ED`,W__`-*6,V8V`?J6?8XVEA.?XP&#-H3TD],C`#-O?P"SR>(!
MLW/V`#/Z_P"ZEK//N0"3V;,!DY53`+/__P#2EK/E-0'^EOV-MI63'^D!@S8$
M]1-9*0"S[R\!LTG_`3/Y]0`S^O(`NI:SPLD`DUFY`1,660"S\O(`TI8S9C8!
MEI9]CC:6DY+C`8,VA/63TR,`L^)R`+/)7P"S<_8`,WK_`+J6,\^Y`)/9LP&3
ME5,`,W__`-*6L^4U`?J6_8VVE1,?Z0&#-@3V$UDI`#-O+P&SR>(!,_GU`#/Z
M_P"ZEK//R0"36;D!$Q99`+/__P#2EC-F-@'^EGV.-I:3G^,!@S:$]I/3(P"S
M[W\`LTG_`;-S]@`S^O(`NI:SPKD`D]FS`9.54P"S\O(`TI:SY34!EI;]C;:5
MDQ+I`8,V!/<362D`L^(B`;/)7P`S^?4`,WK_`+J6,\_)`)-9N0$3%ED`,W__
M`-*6,V8V`?J6?8XVEA.?XP&#-H3WD],C`#-O?P"SR>(!LW/V`#/Z_P"ZEK//
MN0"3V;,!DY53`+/__P#2EK/E-0'^EOV-MI63'^D!@S8$^!-9*0"S[R\!LTG_
M`3/Y]0`S^O(`NI:SPLD`DUFY`1,660"S\O(`TI8S9C8!EI9]CC:6DY+C`8,V
MA/B3TR,`L^)R`+/)7P"S<_8`,WK_`+J6,\^Y`)/9LP&3E5,`,W__`-*6L^4U
M`?J6_8VVE1,?Z0&#-@3Y$UDI`#-O+P&SR>(!,_GU`#/Z_P"ZEK//R0"36;D!
M$Q99`+/__P#2EC-F-@'^EGV.-I:3G^,!@S:$^9/3(P"S[W\`LTG_`;-S]@`S
M^O(`NI:SPKD`D]FS`9.54P"S\O(`TI:SY34!EI;]C;:5DQ+I`8,V!/H362D`
ML^(B`;/Y]0`SR5\`,W__`!/:N0&ZEC-)R0`3EED`,WGY`/J6,V9&`<J6?8X3
MG^,!D],C`#-O?P"S@\8``S:$^K/&X@$S^?,`L___`#J6K8[]CI,560!^EA-:
MN0$VEK/F10$VEH,V!/N3G^D!D]DI`+/O/P$VE[-&_P&S=?8`0I>S\O(`L\9V
M`/V.$Y95`!/8M0$6ES:7LV8&`1,6Z0$362D`-I<S9B8!?8]&EO*5FI^S!M\!
M&.']C3-W]@`S]O\`]8\8Z1SQ#.40[0,WA/N<8+F/`4>5XX,P@2P#-`$L@S2!
M*P,Y`2N#.8$J`SH!*H,Z@2D3`0$M@H#OT*^T01$BX`;D``@3!0`([]"O@K=V
M74PW=^EAMR5%9Y.%%3"&!C=6,A`&!PSADX;FSY=%``"#M05%$P9F1Q,'!Q\,
MY13I$.T8\2,T!0(C.`4"(RP%!J)@`F1!`8*`.7$B^";T2O!.[%;D!OQ2Z%K@
M@``8=9,7-@`4>;J7@A>!DS.WYP`JB;J6*%T35]8!-I<C-/D"(SCI`K*)KH23
M"HD#.>V3!_`#8]\W"9N)"?P;VVD`&PH;`!H*)IJFA1,&``16A>_0CXF3A`0$
M2H7OX%_`XY5$_QL;:P"[B6E!3H;2A5:%[]"/AR,L.0?B<$)THG0">>)I0FJB
M:@)K(6&"@!,*``2[!ZI`/HIC3/8"&PL*`),*B0-:AJ:%5I7OT`^$@R>)!Q,'
M``2[!OH`(RS9!N.>YOI*A;N)24':E._@?[F5MS**Z;<FBEF_.7$B^";T2O!6
MY`;\3NQ2Z(```[J%`I.*A0.3!@#X$U8Z`!-V]@,SA\H`@[D%`Y,'%@`C`-<`
M$P>``ZZ$*HD%)F-8]Q(3!P`$$9^11C.%^@!C=M<4B4=C>O<28Q4'$B:%[^"?
MLA,&@`.!15:%[]!OCY/6"0$3UXD`D_;V#Z(&F]>)`1-W]P]"!]6/D_GY#^()
MV8\;5HH!DU8*`0(6L^<W`1-7B@"3]O8/HA;1CQ-W]P]"%]6/8AK9C[/G1P&\
M^":%[^"?K)Q@)H7A@R,`^0"<8,&#HP#Y`)Q@H8,C`?D`G&"C`?D`G&3A@R,"
M^0"<9,&#HP+Y`)QDH8,C`_D`G&2C`_D`G&CA@R,$^0"<:,&#HP3Y`)QHH8,C
M!?D`G&BC!?D`G&SA@R,&^0"<;,&#HP;Y`)QLH8,C!_D`G&RC!_D`G'#A@R,(
M^0"<<,&#HPCY`)QPH8,C"?D`G'"C"?D`0G3B<*)T`GGB:4)JHFHA86_`?_,3
M!X`#.P;'0(%%,X7Z`._`7_[]M2,`!0#9O2,`!0"C``4`>1<)!>,$!^SMMR,`
M!0"C``4`(P$%`*,!!0!Q%XE'$07C9/?JT;^79@``@[:F'6_`/]\````````!
M``(``````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE
M```````O<')O8R\E:2\E<P``````+@````````!005)?5$5-4```````````
M4$%27U!23T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU
M3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.````````
M`%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$
M14)51P``````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)
M4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.````````
M```Q`````````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?
M3$E"4D%265]0051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%
M```````````E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*````````4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A
M9````````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E
M;7`M)74M)74E<P``````````&`````````!P97)L`````#``````````4$%2
M.CI086-K97(Z.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M````````+64````````M+0```````%1-4$1)4@``5$5-4$1)4@!414U0````
M`%1-4```````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T
M7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A
M8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`]
M(")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H
M*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I
M>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M
M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E
M96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD
M<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=
M*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M
M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R
M;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A
M;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA
M9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I
M+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D
M8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S
M*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S
M*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B
M=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").
M(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES
M("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@
M/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L
M(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S
M="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F
M=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L
M97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM
M;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M
M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-
M04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I
M;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A
M<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;
M(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:
M25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A
M9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E
M<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\
M+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@
M("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L
M("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C
M*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y
M(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO
M72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN
M97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT
M9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L
M("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T
M:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO
M=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D
M;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B
M7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P
M+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B
M*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O
M9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q
M6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT
M<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D
M97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C
M86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`]
M(")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P
M<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=
M.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^
M/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*
M<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<
M,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F
M:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M
M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*
M=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL
M;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA
M;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S
M>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?
M)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB
M4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````
M`````$-!0TA%``")J\WO``````$;`SOL````'````.".__\\!P``C)#__P0!
M``!$D?__&`$``/J1__^0`0``9I+__\@!``!\D___+`(``$B5__^@`@``');_
M_^0"``!\EO__$`,``*Z6__\T`P``:)?__W@#``!TE___G`,``#"9___X`P``
M6)G__R0$``!*FO__<`0``,B=__^P!```(I[__^`$``!RGO__``4``(B?__]4
M!0``II___WP%``"2H/__Z`4``,JE__^<!@``D*?__^`&``!&J/__@`<``'J[
M___$!P``U+O__^P'``"^O/__,`@``':^__]P"````````!```````````WI2
M``%\`0$;#0(`$````!@```"`C___(@`````'`0!T````+````"20__^V````
M`$(.4$:(!($"B09"#`@`3)<24I,*E`R5#F:2")80:-)"TT+40M5"UD+70L%"
MR`P"4$3)0@X`0@T(@0*(!(D&D@B3"I0,E0Z6$)<24M+3U-76UT27$D+71),*
ME`R5#I<21M-"U$+50M<T````I````&*0__]L`````$(.L`%&B`2)!I((0@P(
M`$*!`@)2"L%"R`P"L`%"R4+20@X`0@L``&````#<````EI#__Q8!````0@[0
M`4:(!)0,@0)"#`@`6HD&1LE2P4+(#`+0`4+40@X`0@T(@0*(!(D&E`Q$D@B3
M"G*5#@)<U50*R4+20M-""U*5#DC)TM/52(D&D@B3"I4.``!P````0`$``$B1
M___,`0```$(.<%*(!(D&D@B3"I4.@0*4#)<2F!1"#`@``MX*P4+(#`)P0LE"
MTD+30M1"U4+70MA"#@!""W"6$)D6FA@"6`K60ME"VD8+5M;9VD26$)D6FAA&
MUMG:1I80F1::&$;60ME"VD````"T`0``H)+__]0`````0@Y03(@$B0:2"),*
ME`R5#D(,"`!6@0("9@H,`E!"P4+(0LE"TD+30M1"U4(.`$(+````*````/@!
M```PD___8`````!"#B!"B09,B`2!`D(,"`!FR`P"($3!0LE>#@`@````)`(`
M`&23__\R`````$(.$$J(`D(,"`!"R`P"$%X.``!`````2`(``'*3__^Z````
M`$(.8$:!`H@$B09"#`@`2I((DPJ4#)4.`HX*#`)@0L%$R$+)0M)"TT+40M5"
M#@!""P```"````",`@``Z)/__PP`````0@X00H@"0@P(`$+(#`(00@X``%@`
M``"P`@``T)/__[P!````0@Z``DJ(!(D&D@B3"I@40@P(`&*!`I0,E0Z6$)<2
MF1::&)L:`E`*#`*``D+!0LA"R4+20M-"U$+50M9"UT+80ME"VD+;0@X`0@L`
M*`````P#```PE?__*`````!"#B!&B`2)!H$"0@P(`%+(#`(@0L%$R4(.``!(
M````.`,``"R5___R`````$(.0$J(!),*@0*)!I((0@P(``*>"@P"0$+!0LA"
MR4+20M-"#@!""U(*#`)`0L%"R$+)0M)"TTH.`$0+/````(0#``#2E?__?@,`
M``!"#D!*B`2)!I((DPJ4#$(,"`!"@0(#*@,*R`P"0$+!0LE"TD+30M12#@!$
M"P```"P```#$`P``$)G__UH`````0@XP1(@$B09"#`@`0H$"`D`*P4+(#`(P
M0LE"#@!""QP```#T`P``.IG__U``````0@Y@1(@4@1)"#`A`````4````!0$
M``!JF?__%@$```!"#G!8B`24#)4.FAB!`HD&D@B3"I80EQ*8%)D60@P(``*X
M"@P"<$+!0LA"R4+20M-"U$+50M9"UT+80ME"VD(.`$(+)````&@$```LFO__
M'@````!"#A!$B`2!`D(,"`!0P4+(#`(00@X``&@```"0!```(IK__^P`````
M0@Y`1H@$D@B3"D(,"`!B@0),B09<"L%"R`P"0$+)0M)"TT(.`$(+0LE:R`P"
M0$+!0M)"TT(.`$0-"($"B`2)!I((DPI$"I0,`D;40LE*"T*4#$3)U$2)!I0,
M`+````#\!```HIK__S@%````0@Z@`T2(!)((0@P(`&"3"I0,@0*)!@*,E0Z6
M$)<2F!29%@-P`0K!0L@,`J`#0M9"UT+80ME"R4+20M-"U$350@X`0@L"@)H8
M1MIBU=;7V-E6R`P"H`-"P4+20M-"U$3)0@X`1`T(@0*(!(D&D@B3"I0,E0Z6
M$)<2F!29%IH8`S`!"MI""P/B`-I"FAA$U=;7V-G:3)4.EA"7$I@4F1::&```
M`$````"P!0``)I___\8!````0@Y00HD&5(@$DPJ4#($"D@B5#D(,"``#5`$*
MP4+(#`)00LE"TD+30M1"U4(.`$(+````6````/0%``"HH/__M@````!"#D!&
MB`2)!I((0@P(`&"!`FP*P4+(#`)`0LE"TD(.`$(+1),*;`K30@M.R`P"0$+3
M0L%"R4320@X`1`T(@0*(!(D&D@A"DPH```!`````4`8``)R'__^L`0```$(.
M8$:!`H@$D@A"#`@`1HD&DPJ4#`,L`0K!0L@,`F!"R4+20M1$TT(.`$(+````
M`````$````"4!@``OJ#__S03````1`[0!4B(!(D&0@P(`%2!`I((DPJ4#)4.
M`_`2"L%$R`P"T`5$R4321--$U$351`X`0@L`)````-@&``"NL___6@````!"
M#A!$B`2!`D(,"``"3,%"R`P"$$(.`$``````!P``X+/__^H`````0@Y`4(@$
MB0:2"),*E0Z!`I0,EA!"#`@``GH*P4+(#`)`0LE"TD+30M1"U4+60@X`0@L`
M/````$0'``"&M/__N`$```!"#D!.B`2)!I((E0Z!`I,*E`Q"#`@``TP!"L@,
M`D!"P4+)0M)"TT+40M5"#@!$"Q````"$!P``_K7__PP`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````!```````````#`````````0``````
M```0`P````````$`````````&@,````````@`````````)"K````````(0``
M```````(`````````!D`````````F*L````````;``````````@`````````
M&@````````"@JP```````!P`````````"`````````#U_O]O`````-@"````
M````!0````````!8#0````````8`````````R`,````````*`````````,0$
M````````"P`````````8`````````!4````````````````````#````````
M`+BM`````````@````````!P!0```````!0`````````!P`````````7````
M`````%@5````````!P````````!($P````````@`````````@`<````````)
M`````````!@`````````'@`````````(`````````/O__V\``````0``"```
M``#^__]O`````.@2````````____;P`````"`````````/#__V\`````'!(`
M``````#Y__]O``````L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````T!H```````#0&@```````-`:
M````````T!H```````#0&@```````-`:````````T!H```````#0&@``````
M`-`:````````T!H```````#0&@```````-`:````````T!H```````#0&@``
M`````-`:````````T!H```````#0&@```````-`:````````T!H```````#0
M&@```````-`:````````T!H```````#0&@```````-`:````````T!H`````
M``#0&@```````-`:````````T!H```````#0&@```````-`:````````T!H`
M``````#0&@```````-`:````````T!H```````#0&@```````-`:````````
MT!H```````#0&@```````-`:````````T!H```````#0&@```````-`:````
M````T!H```````#0&@```````-`:````````T!H```````#0&@```````-`:
M````````T!H```````#0&@```````-`:````````T!H```````#0&@``````
M`-`:````````T!H```````#0&@```````-`:````````T!H```````"HJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H56)U;G1U(#$S+C(N,"TY=6)U;G1U,2D@,3,N,BXP`$%2````<FES
M8W8``4@````$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?
M>FEC<W(R<#!?>FEF96YC96DR<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R
M`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I
M<V-V+F%T=')I8G5T97,`````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````<`(```````!P`@```````"$````````````````````!````````
M````````````$P````<````"`````````)0"````````E`(````````D````
M````````````````!````````````````````"8````'`````@````````"X
M`@```````+@"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````V`(```````#8`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````,@#````````
MR`,```````"0"0````````8````"````"``````````8`````````$8````#
M`````@````````!8#0```````%@-````````Q`0```````````````````$`
M``````````````````!.````____;P(`````````'!(````````<$@``````
M`,P`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````.@2````````Z!(```````!@``````````8````"````"```````````
M`````````&H````$`````@````````!($P```````$@3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````6!4`
M``````!8%0```````'`%````````!0```!0````(`````````!@`````````
M>0````$````&`````````-`:````````T!H```````#``P``````````````
M````$``````````0`````````'X````!````!@````````"0'@```````)`>
M````````HB\```````````````````0```````````````````"$`````0``
M``(`````````.$X````````X3@```````'A!```````````````````(````
M````````````````C`````$````"`````````+"/````````L(\```````#L
M````````````````````!````````````````````)H````!`````@``````
M``"@D````````*"0````````F`<```````````````````@`````````````
M``````"D````$`````,`````````D*L```````"0FP````````@`````````
M```````````!``````````@`````````LP````X````#`````````)BK````
M````F)L````````(````````````````````"``````````(`````````+\`
M```/`````P````````"@JP```````*";````````"```````````````````
M``@`````````"`````````#+````!@````,`````````J*L```````"HFP``
M`````!`"````````!@`````````(`````````!``````````U`````$````#
M`````````+BM````````N)T```````!(`@``````````````````"```````
M```(`````````-D````!`````P``````````L`````````"@````````4```
M``````````````````@```````````````````#?````"`````,`````````
M4+````````!0H````````"@````````````````````(````````````````
M````Y`````$````P````````````````````4*`````````E````````````
M`````````0`````````!`````````.T````#``!P````````````````````
M`'6@````````4P````````````````````$````````````````````!````
M`P````````````````````````#(H````````/\````````````````````!
/````````````````````
